"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createBalanceBuilder = void 0;
require("@moonbeam-network/api-augment");
const balance_constants_1 = require("./balance.constants");
/* eslint-disable @typescript-eslint/no-use-before-define */
function createBalanceBuilder() {
    return {
        assets,
        min,
        system,
        tokens: (asset) => tokens(asset),
    };
}
exports.createBalanceBuilder = createBalanceBuilder;
function assets(asset) {
    return {
        pallet: balance_constants_1.BalancePallet.Assets,
        function: balance_constants_1.BalanceFunction.Account,
        path: ['balance'],
        getParams: (account) => [asset, account],
        calc: (balance) => balance.toBigInt(),
    };
}
function min(asset) {
    return {
        pallet: balance_constants_1.BalancePallet.Assets,
        function: balance_constants_1.BalanceFunction.Asset,
        path: ['minBalance'],
        params: [asset],
    };
}
function system() {
    return {
        pallet: balance_constants_1.BalancePallet.System,
        function: balance_constants_1.BalanceFunction.Account,
        path: ['data'],
        getParams: (account) => [account],
        calc: ({ free, miscFrozen }) => BigInt(free.sub(miscFrozen).toString()),
    };
}
function tokens(asset) {
    return {
        pallet: balance_constants_1.BalancePallet.Tokens,
        function: balance_constants_1.BalanceFunction.Accounts,
        path: [],
        getParams: (account) => [
            account,
            Number.isInteger(asset)
                ? { ForeignAsset: asset }
                : { Token: asset },
        ],
        calc: ({ free, frozen }) => BigInt(free.sub(frozen).toString()),
    };
}
//# sourceMappingURL=balance.js.map