"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.moonriver = exports.moonbeam = exports.moonbase = exports.createConfigGetter = void 0;
const constants_1 = require("../constants");
const moonbase_1 = require("./moonbase");
const moonbeam_1 = require("./moonbeam");
const moonriver_1 = require("./moonriver");
function createConfigGetter(assets, moonAsset, moonChain, chains, configs) {
    return {
        asset: moonAsset,
        assets,
        chain: moonChain,
        deposit: (asset) => {
            const config = configs[asset];
            if (!config) {
                throw new Error(`No config found for asset: ${asset}`);
            }
            return {
                chains: Object.keys(config.deposit).map((chain) => chains[chain]),
                from: (chain) => {
                    const depositConfig = config.deposit[chain];
                    if (!depositConfig) {
                        throw new Error(`No deposit config found for asset: ${asset} and chain: ${chain}`);
                    }
                    return {
                        asset: config.asset,
                        origin: config.origin,
                        config: depositConfig,
                    };
                },
            };
        },
        withdraw: (asset) => {
            const config = configs[asset];
            if (!config) {
                throw new Error(`No config found for asset: ${asset}`);
            }
            return {
                chains: Object.keys(config.withdraw).map((chain) => chains[chain]),
                to: (chain) => {
                    const withdrawConfig = config.withdraw[chain];
                    if (!withdrawConfig) {
                        throw new Error(`No withdraw config found for asset: ${asset} and chain: ${chain}`);
                    }
                    return {
                        asset: config.asset,
                        origin: config.origin,
                        config: withdrawConfig,
                    };
                },
            };
        },
    };
}
exports.createConfigGetter = createConfigGetter;
exports.moonbase = createConfigGetter(moonbase_1.MOONBASE_ASSETS_CONFIGS, moonbase_1.MOONBASE_ASSETS_CONFIGS[constants_1.Asset.DEV], constants_1.MOON_CHAINS_CONFIGS[constants_1.MoonChain.MoonbaseAlpha], moonbase_1.MOONBASE_CHAINS_CONFIGS, moonbase_1.MOONBASE_CONFIGS);
exports.moonbeam = createConfigGetter(moonbeam_1.MOONBEAM_ASSETS_CONFIGS, moonbeam_1.MOONBEAM_ASSETS_CONFIGS[constants_1.Asset.GLMR], constants_1.MOON_CHAINS_CONFIGS[constants_1.MoonChain.Moonbeam], moonbeam_1.MOONBEAM_CHAINS_CONFIGS, moonbeam_1.MOONBEAM_CONFIGS);
exports.moonriver = createConfigGetter(moonriver_1.MOONRIVER_ASSETS_CONFIGS, moonriver_1.MOONRIVER_ASSETS_CONFIGS[constants_1.Asset.MOVR], constants_1.MOON_CHAINS_CONFIGS[constants_1.MoonChain.Moonriver], moonriver_1.MOONRIVER_CHAINS_CONFIGS, moonriver_1.MOONRIVER_CONFIGS);
//# sourceMappingURL=config.js.map