"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MOVR = void 0;
const constants_1 = require("../../../constants");
const extrinsic_1 = require("../../../extrinsic");
const config_utils_1 = require("../../config.utils");
const moonriver_common_1 = require("../moonriver.common");
const asset = moonriver_common_1.assets[constants_1.Asset.MOVR];
const bifrost = moonriver_common_1.chains[constants_1.Chain.Bifrost];
const karura = moonriver_common_1.chains[constants_1.Chain.Karura];
const khala = moonriver_common_1.chains[constants_1.Chain.Khala];
const parallel = moonriver_common_1.chains[constants_1.Chain.Parallel];
const shiden = moonriver_common_1.chains[constants_1.Chain.Shiden];
const karuraMovrId = (0, config_utils_1.getMoonAssetId)(karura);
const khalaMovrId = (0, config_utils_1.getMoonAssetId)(khala);
const parallelMovrId = (0, config_utils_1.getMoonAssetId)(parallel);
const shidenMovrId = (0, config_utils_1.getMoonAssetId)(shiden);
exports.MOVR = {
    asset,
    origin: moonriver_common_1.moonriver,
    deposit: {
        [bifrost.chain]: {
            origin: bifrost,
            balance: moonriver_common_1.balance.tokens('MOVR'),
            sourceFeeBalance: moonriver_common_1.balance.system(),
            extrinsic: moonriver_common_1.extrinsic
                .xTokens()
                .transfer()
                .successEvent(extrinsic_1.XTokensExtrinsicSuccessEvent.TransferredMultiAssets)
                .origin(bifrost)
                .asset({
                Token: asset.originSymbol,
            }),
        },
        [karura.chain]: {
            origin: karura,
            balance: moonriver_common_1.balance.tokens(karuraMovrId),
            sourceFeeBalance: moonriver_common_1.balance.system(),
            extrinsic: moonriver_common_1.extrinsic
                .xTokens()
                .transfer()
                .successEvent(extrinsic_1.XTokensExtrinsicSuccessEvent.TransferredMultiAssets)
                .origin(karura)
                .asset({
                ForeignAsset: karuraMovrId,
            }),
        },
        [khala.chain]: {
            origin: khala,
            balance: moonriver_common_1.balance.assets(khalaMovrId),
            sourceFeeBalance: moonriver_common_1.balance.system(),
            extrinsic: moonriver_common_1.extrinsic
                .xTransfer()
                .transfer()
                .successEvent(extrinsic_1.XTransferExtrinsicSuccessEvent.Withdrawn)
                .origin(khala)
                .X2((0, config_utils_1.getPalletInstance)(khala)),
        },
        [parallel.chain]: {
            origin: parallel,
            balance: moonriver_common_1.balance.assets(parallelMovrId),
            sourceFeeBalance: moonriver_common_1.balance.system(),
            extrinsic: moonriver_common_1.extrinsic
                .xTokens()
                .transfer()
                .successEvent(extrinsic_1.XTokensExtrinsicSuccessEvent.TransferredMultiAssets)
                .origin(parallel)
                .asset(parallelMovrId),
        },
        [shiden.chain]: {
            origin: shiden,
            balance: moonriver_common_1.balance.assets(shidenMovrId),
            sourceFeeBalance: moonriver_common_1.balance.system(),
            extrinsic: moonriver_common_1.extrinsic
                .polkadotXcm()
                .limitedReserveWithdrawAssets()
                .successEvent(extrinsic_1.PolkadotXcmExtrinsicSuccessEvent.Attempted)
                .origin(shiden)
                .V1()
                .X2((0, config_utils_1.getPalletInstance)(shiden)),
        },
    },
    withdraw: {
        [bifrost.chain]: moonriver_common_1.withdraw.xTokens({
            balance: moonriver_common_1.balance.tokens('MOVR'),
            destination: bifrost,
            feePerWeight: 213600,
        }),
        [karura.chain]: moonriver_common_1.withdraw.xTokens({
            balance: moonriver_common_1.balance.tokens(karuraMovrId),
            destination: karura,
            feePerWeight: 50000,
        }),
        [khala.chain]: moonriver_common_1.withdraw.xTokens({
            balance: moonriver_common_1.balance.tokens(khalaMovrId),
            destination: khala,
            feePerWeight: 50000,
        }),
        [parallel.chain]: moonriver_common_1.withdraw.xTokens({
            balance: moonriver_common_1.balance.assets(parallelMovrId),
            destination: parallel,
            feePerWeight: 0.48,
        }),
        [shiden.chain]: moonriver_common_1.withdraw.xTokens({
            balance: moonriver_common_1.balance.assets(shidenMovrId),
            destination: shiden,
            feePerWeight: 50000,
        }),
    },
};
//# sourceMappingURL=movr.js.map